/* TEKNISA

Nome: NUTRIENTE_DO_CARDAPIO_PME

Descrio:
   Clculo dos Nutrientes do Cardapio e gravao na tabela NUTRTRAB.

   P_CDFILCENTPME - Filial Central de Merenda
   P_CDFILIAL     - Filial agregada
   P_CDSERVFILI   - String contendo sequencia de Servios a serem calculados.
   P_NUTRIENTES   - String contendo Nutrientes a serem calculados.
   P_NRSEQUNUTR   - Nmero sequencial a ser utilizado para gravao dos dados.
   P_IDNDPCAL     - Indicador de calculo do NDPCal.
   P_DTINICIAL    - Data inicial.
   P_DTFINAL      - Data final.


Criao:
02/05/2005 - Henrique Dias Borges

Manutenes:

11/05/2005  Rafael Christopher - Alterao de Tipos de campos para variveis.

****************************************************************
             CORREO DO CLCULO DO NDPCAL%
****************************************************************
A frmula usada para clculo do NDPCal% :

NDPCAL% = NPU * Sum(Protenas) * 4
          ------------------------
                    VCT

onde:

NPU = Somatrio das protenas dos componentes da receita multiplicados
      pelo Fator de Clculo de NDPCAL, informado na tela de parametrizao
      por grupo de produtos, sendo 0,7 para alimentos de origem animal;
      0,6 para leguminosas e 0,5 para cereais, frutas e outros vegetais.
Sum(Protenas) = Somatrio das protenas dos componentes da receita
VCT = "Valor Calrico Total" = Soma(carboidratos) x 4 +
                               Soma(lipdeos)    x 9  +
                               Soma(protenas)   x 4  +
                               Soma(lcoois)     x 7
****************************************************************

*/
IF EXISTS(SELECT name FROM sysobjects
          WHERE name = 'NUTRIENTE_DO_CARDAPIO_PME' AND type = 'P')
  DROP PROCEDURE NUTRIENTE_DO_CARDAPIO_PME
  GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO


CREATE PROCEDURE NUTRIENTE_DO_CARDAPIO_PME @P_CDFILCENTPME  VARCHAR(4),
                                           @P_CDFILIAL      VARCHAR(4),
                                           @P_CDSERVFILI    VARCHAR(2000),
                                           @P_NUTRIENTES    VARCHAR(2000),
                                           @P_NRSEQUNUTR    VARCHAR(10),
                                           @P_IDNDPCAL      VARCHAR(1),
                                           @P_DTINICIAL     DATETIME,
                                           @P_DTFINAL       DATETIME,
                                           @P_CDTIPOCARD    VARCHAR(10)

AS
   DECLARE @V_QTCARBOIDRATO DOUBLE PRECISION;
   DECLARE @V_QTPROTEINA    DOUBLE PRECISION;
   DECLARE @V_QTLIPIDEO     DOUBLE PRECISION;
   DECLARE @V_QTALCOOL      DOUBLE PRECISION;
   DECLARE @V_QTCALORIA     DOUBLE PRECISION;

   DECLARE @V_NUTRTRAB_CDFILCENTPME VARCHAR(4);
   DECLARE @V_NUTRTRAB_CDFILIAL     VARCHAR(4);
   DECLARE @V_NUTRTRAB_CDSERVFILI   VARCHAR(5);
   DECLARE @V_NUTRTRAB_DTCARDIAPME  DATETIME;
   DECLARE @V_NUTRTRAB_CDDIETPAD    VARCHAR(4);
   DECLARE @V_NUTRTRAB_NRSEQPRACPME NUMERIC(3);
   DECLARE @V_NUTRTRAB_CDTIPOPRAT   VARCHAR(2);
   DECLARE @V_NUTRTRAB_CDFILAUXPRAT VARCHAR(4);
   DECLARE @V_NUTRTRAB_CDPRATO      VARCHAR(10);
   DECLARE @V_NUTRTRAB_CDPRODUTO    VARCHAR(10);
   DECLARE @V_NUTRTRAB_SGUNIDPROD   VARCHAR(10);
   DECLARE @V_NUTRTRAB_CDNUTRIENTE  VARCHAR(3);
   DECLARE @V_NUTRTRAB_QTPRODUTO    DOUBLE PRECISION;
   DECLARE @V_NUTRTRAB_QTNUTPROD    DOUBLE PRECISION;
   DECLARE @V_NUTRTRAB_VRPECONSCARD DOUBLE PRECISION;
   DECLARE @V_NUTRTRAB_QTPRODPRATT  DOUBLE PRECISION;
BEGIN
   DECLARE CUR_NUTRTRAB CURSOR FOR
      SELECT CD.CDFILCENTPME, CD.CDFILIAL, CD.CDSERVFILI, CD.DTCARDIAPME, 'XXXX' AS CDDIETPAD, CC.NRSEQPRACPME,
             CC.CDTIPOPRAT, CC.CDFILAUXPRAT, CC.CDPRATO, RS.CDPRODUTO, RS.SGUNIDADE AS SGUNIDPROD, NP.CDNUTRIENTE,
             ISNULL(RS.QTCALCNUTRSE,0) AS QTPRODUTO,
             ISNULL((NP.QTNUTRPROD * 10 * ISNULL((CASE PRODFILI.VRPESOUNIDFI WHEN 0 THEN PR.VRPESOUNID ELSE PRODFILI.VRPESOUNIDFI END), PR.VRPESOUNID) * RS.QTCALCNUTRSE), 0) AS QTNUTPROD,
             ISNULL(CC.VRPECONSCPME,0) AS VRPECONSCARD, RS.QTBRUTASEUNR AS QTPRODPRATT
        FROM PRODFILI, PRODUTO PR, NUTRPROD NP, COMPCARDPME CC, RECESERV RS, CARDAPIOPME CP,
             (SELECT CDFILCENTPME, NRCARDPME, NRCARDIAPME, @P_CDFILIAL AS CDFILIAL, CDSERVFILI, DTCARDIAPME
                FROM CARDIAPME P
               WHERE (P.CDFILCENTPME = @P_CDFILCENTPME ) 
                 AND ((CHARINDEX(P.CDSERVFILI, @P_CDSERVFILI) <> 0) OR (@P_CDSERVFILI = 'T')) 
                 AND (P.CDFILIAL     = @P_CDFILCENTPME    ) 
                 AND (P.DTCARDIAPME BETWEEN @P_DTINICIAL AND @P_DTFINAL ) 
                 AND (NOT EXISTS(SELECT CDFILIAL
                                   FROM CARDIAPME C
                                  WHERE (C.CDFILCENTPME = P.CDFILCENTPME ) 
                                    AND (C.NRCARDPME    = P.NRCARDPME    ) 
                                    AND (C.CDSERVFILI   = P.CDSERVFILI   ) 
                                    AND (C.CDFILIAL     = @P_CDFILIAL    ) 
                                    AND (C.DTCARDIAPME  = P.DTCARDIAPME  ) 
                                    AND (C.IDCARDESPEC  = 'S'            )))
               UNION ALL
              SELECT CDFILCENTPME, NRCARDPME, NRCARDIAPME, @P_CDFILIAL AS CDFILIAL, CDSERVFILI, DTCARDIAPME
                FROM CARDIAPME
               WHERE (CDFILCENTPME = @P_CDFILCENTPME ) 
                 AND ((CHARINDEX(CDSERVFILI, @P_CDSERVFILI) <> 0) OR (@P_CDSERVFILI = 'T')) 
                 AND (CDFILIAL     = @P_CDFILIAL     ) 
                 AND (DTCARDIAPME BETWEEN @P_DTINICIAL AND @P_DTFINAL) 
                 AND (IDCARDESPEC  = 'S'             )) CD
       WHERE (CD.CDFILCENTPME    = CC.CDFILCENTPME)     
         AND (CD.NRCARDPME       = CC.NRCARDPME   )     
         AND (CD.NRCARDIAPME     = CC.NRCARDIAPME )     
         AND (CD.CDFILIAL        = RS.CDFILIAL    )    
         AND (CD.CDSERVFILI      = RS.CDSERVFILI  )     
         AND (CC.CDFILAUXPRAT    = RS.CDFILAUXPRAT)     
         AND (CC.CDPRATO         = RS.CDPRATO     )     
         AND (PRODFILI.CDFILIAL  = CD.CDFILCENTPME)     
         AND (PRODFILI.CDPRODUTO = PR.CDPRODUTO   )     
         AND (CHARINDEX(NP.CDNUTRIENTE, @P_NUTRIENTES) <> 0) 
         AND (RS.CDPRODUTO = NP.CDPRODUTO         )     
         AND (RS.CDPRODUTO = PR.CDPRODUTO         )     
         AND (CD.CDFILCENTPME    = CP.CDFILCENTPME)     
         AND (CD.NRCARDPME       = CP.NRCARDPME)        
         AND (CP.CDTIPOCARD      = @P_CDTIPOCARD)
       UNION ALL
      SELECT CD.CDFILCENTPME, CD.CDFILIAL, CD.CDSERVFILI, CD.DTCARDIAPME, 'XXXX' AS CDDIETPAD, CC.NRSEQPRACPME,
             CC.CDTIPOPRAT, CC.CDFILAUXPRAT, CC.CDPRATO, RF.CDPRODUTO, RF.SGUNIDADE AS SGUNIDPROD, NP.CDNUTRIENTE,
             ISNULL(RF.QTCALCNUTRLO,0) AS QTPRODUTO,
             ISNULL((NP.QTNUTRPROD * 10 * ISNULL((CASE PRODFILI.VRPESOUNIDFI WHEN 0 THEN PR.VRPESOUNID ELSE PRODFILI.VRPESOUNIDFI END), PR.VRPESOUNID) * RF.QTCALCNUTRLO), 0) AS QTNUTPROD,
             ISNULL(CC.VRPECONSCPME,0) AS VRPECONSCARD, RF.QTBRUTALOUNR AS QTPRODPRATT
        FROM PRODFILI, PRODUTO PR, NUTRPROD NP, COMPCARDPME CC, RECEFILI RF, CARDAPIOPME CP,
             (SELECT CDFILCENTPME, NRCARDPME, NRCARDIAPME, @P_CDFILIAL AS CDFILIAL, CDSERVFILI, DTCARDIAPME
                FROM CARDIAPME P
               WHERE (P.CDFILCENTPME = @P_CDFILCENTPME ) 
                 AND ((CHARINDEX(P.CDSERVFILI, @P_CDSERVFILI) <> 0) OR (@P_CDSERVFILI = 'T')) 
                 AND (P.CDFILIAL     = @P_CDFILCENTPME     ) 
                 AND (P.DTCARDIAPME BETWEEN @P_DTINICIAL AND @P_DTFINAL) 
                 AND (NOT EXISTS(SELECT CDFILIAL
                                   FROM CARDIAPME C
                                  WHERE (C.CDFILCENTPME = P.CDFILCENTPME ) 
                                    AND (C.NRCARDPME    = P.NRCARDPME    ) 
                                    AND (C.CDSERVFILI   = P.CDSERVFILI   ) 
                                    AND (C.CDFILIAL     = @P_CDFILIAL    ) 
                                    AND (C.DTCARDIAPME  = P.DTCARDIAPME  ) 
                                    AND (C.IDCARDESPEC  = 'S'            )))
               UNION ALL
              SELECT CDFILCENTPME, NRCARDPME, NRCARDIAPME, @P_CDFILIAL AS CDFILIAL, CDSERVFILI, DTCARDIAPME
                FROM CARDIAPME
          WHERE
             (CDFILCENTPME = @P_CDFILCENTPME ) AND
             ((CHARINDEX(CDSERVFILI, @P_CDSERVFILI) <> 0) OR (@P_CDSERVFILI = 'T')) AND
             (CDFILIAL     = @P_CDFILCENTPME       ) AND
             (DTCARDIAPME BETWEEN @P_DTINICIAL AND @P_DTFINAL)  AND
             (IDCARDESPEC  = 'S'             )
         ) CD
      WHERE
         (CD.CDFILCENTPME    = CC.CDFILCENTPME )    AND
         (CD.NRCARDPME       = CC.NRCARDPME    )    AND
         (CD.NRCARDIAPME     = CC.NRCARDIAPME  )    AND
         (CD.CDFILIAL        = RF.CDFILIAL     )    AND
         (CC.CDFILAUXPRAT    = RF.CDFILAUXPRAT )    AND
         (CC.CDPRATO         = RF.CDPRATO      )    AND
         (PRODFILI.CDFILIAL  = CD.CDFILCENTPME )    AND
         (PRODFILI.CDPRODUTO = PR.CDPRODUTO    )    AND
         (CHARINDEX(NP.CDNUTRIENTE, @P_NUTRIENTES) <> 0) AND
         (RF.CDPRODUTO = NP.CDPRODUTO          )    AND
         (RF.CDPRODUTO = PR.CDPRODUTO          )    AND
         (CD.CDFILCENTPME    = CP.CDFILCENTPME)     AND
         (CD.NRCARDPME       = CP.NRCARDPME)        AND
         (CP.CDTIPOCARD      = @P_CDTIPOCARD)       AND
         (NOT EXISTS (SELECT
                         CDPRATO
                      FROM
                         RECESERV
                      WHERE
                         (CDFILAUXPRAT = CC.CDFILAUXPRAT ) AND
                         (CDPRATO      = CC.CDPRATO      ) AND
                         (CDFILIAL     = CD.CDFILIAL     ) AND
                         (CDSERVFILI   = CD.CDSERVFILI   )))
       UNION ALL
      SELECT CD.CDFILCENTPME, CD.CDFILIAL, CD.CDSERVFILI, CD.DTCARDIAPME, 'XXXX' AS CDDIETPAD, CC.NRSEQPRACPME,
             CC.CDTIPOPRAT, CC.CDFILAUXPRAT, CC.CDPRATO, RT.CDPRODUTO, RT.SGUNIDADE AS SGUNIDPROD, NP.CDNUTRIENTE,
             ISNULL(RT.QTCALCNUTRPRTP,0) AS QTPRODUTO, 
             ISNULL((NP.QTNUTRPROD * 10 * ISNULL((CASE PRODFILI.VRPESOUNIDFI WHEN 0 THEN PR.VRPESOUNID ELSE PRODFILI.VRPESOUNIDFI END), PR.VRPESOUNID) * RT.QTCALCNUTRPRTP), 0) AS QTNUTPROD,
             ISNULL(CC.VRPECONSCPME,0) VRPECONSCARD, RT.QTBRUTAPRUNRTP AS QTPRODPRATT
        FROM PRODFILI, PRODUTO PR, NUTRPROD NP, COMPCARDPME CC, RECETPCARD RT, CARDAPIOPME CP,
             (SELECT CDFILCENTPME, NRCARDPME, NRCARDIAPME, @P_CDFILIAL AS CDFILIAL, CDSERVFILI, DTCARDIAPME
                FROM CARDIAPME P
               WHERE (P.CDFILCENTPME = @P_CDFILCENTPME ) 
                 AND ((CHARINDEX(P.CDSERVFILI, @P_CDSERVFILI) <> 0) OR (@P_CDSERVFILI = 'T')) 
                 AND (P.CDFILIAL     = @P_CDFILCENTPME     ) 
                 AND (P.DTCARDIAPME BETWEEN @P_DTINICIAL AND @P_DTFINAL) 
                 AND (NOT EXISTS(SELECT CDFILIAL
                                   FROM CARDIAPME C
                                  WHERE (C.CDFILCENTPME = P.CDFILCENTPME ) 
                                    AND (C.NRCARDPME    = P.NRCARDPME    ) 
                                    AND (C.CDSERVFILI   = P.CDSERVFILI   ) 
                                    AND (C.CDFILIAL     = @P_CDFILIAL    ) 
                                    AND (C.DTCARDIAPME  = P.DTCARDIAPME  ) 
                                    AND (C.IDCARDESPEC  = 'S'            )))
               UNION ALL
              SELECT CDFILCENTPME, NRCARDPME, NRCARDIAPME,@P_CDFILIAL AS CDFILIAL, CDSERVFILI, DTCARDIAPME
                FROM CARDIAPME
               WHERE (CDFILCENTPME = @P_CDFILCENTPME ) 
                 AND ((CHARINDEX(CDSERVFILI, @P_CDSERVFILI) <> 0) OR (@P_CDSERVFILI = 'T')) 
                 AND (CDFILIAL     = @P_CDFILCENTPME     ) 
                 AND (DTCARDIAPME BETWEEN @P_DTINICIAL AND @P_DTFINAL) 
                 AND (IDCARDESPEC  = 'S'             )) CD
       WHERE (CD.CDFILCENTPME    = CC.CDFILCENTPME ) 
         AND (CD.NRCARDPME       = CC.NRCARDPME    ) 
         AND (CD.NRCARDIAPME     = CC.NRCARDIAPME  ) 
         AND (RT.CDFILAUXPRAT    = CC.CDFILAUXPRAT ) 
         AND (CC.CDPRATO         = RT.CDPRATO      ) 
         AND (PRODFILI.CDFILIAL  = CD.CDFILCENTPME ) 
         AND (PRODFILI.CDPRODUTO = PR.CDPRODUTO    ) 
         AND (CHARINDEX(NP.CDNUTRIENTE, @P_NUTRIENTES) <> 0) 
         AND (RT.CDPRODUTO = NP.CDPRODUTO          ) 
         AND (RT.CDPRODUTO = PR.CDPRODUTO          ) 
         AND (CD.CDFILCENTPME    = CP.CDFILCENTPME ) 
         AND (CD.NRCARDPME       = CP.NRCARDPME    ) 
         AND (CP.CDTIPOCARD      = @P_CDTIPOCARD   )
         AND (RT.CDTIPOCARD      = CP.CDTIPOCARD   )
         AND (RT.CDFILCENTPME    = CC.CDFILCENTPME )
         AND (NOT EXISTS (SELECT CDPRATO
                            FROM RECEFILI
                           WHERE (CDFILAUXPRAT = CC.CDFILAUXPRAT ) 
                             AND (CDPRATO      = CC.CDPRATO      ) 
                             AND (CDFILIAL     = CD.CDFILIAL     )))
         AND (NOT EXISTS (SELECT CDPRATO
                            FROM RECESERV
                           WHERE (CDFILAUXPRAT = CC.CDFILAUXPRAT ) 
                             AND (CDPRATO      = CC.CDPRATO      ) 
                             AND (CDFILIAL     = CD.CDFILIAL     ) 
                             AND (CDSERVFILI   = CD.CDSERVFILI   )))
       UNION ALL
      SELECT CD.CDFILCENTPME, CD.CDFILIAL, CD.CDSERVFILI, CD.DTCARDIAPME, 'XXXX' AS CDDIETPAD, CC.NRSEQPRACPME,
             CC.CDTIPOPRAT, CC.CDFILAUXPRAT, CC.CDPRATO, RP.CDPRODUTO, RP.SGUNIDADE AS SGUNIDPROD, NP.CDNUTRIENTE,
             ISNULL(RP.QTCALCNUTRPR,0) AS QTPRODUTO, 
             ISNULL((NP.QTNUTRPROD * 10 * ISNULL((CASE PRODFILI.VRPESOUNIDFI WHEN 0 THEN PR.VRPESOUNID ELSE PRODFILI.VRPESOUNIDFI END), PR.VRPESOUNID) * RP.QTCALCNUTRPR), 0) AS QTNUTPROD,
             ISNULL(CC.VRPECONSCPME,0) VRPECONSCARD, RP.QTBRUTAPRUNR AS QTPRODPRATT
        FROM PRODFILI, PRODUTO PR, NUTRPROD NP, COMPCARDPME CC, RECEPADR RP, CARDAPIOPME CP,
             (SELECT CDFILCENTPME, NRCARDPME, NRCARDIAPME, @P_CDFILIAL AS CDFILIAL, CDSERVFILI, DTCARDIAPME
                FROM CARDIAPME P
               WHERE (P.CDFILCENTPME = @P_CDFILCENTPME ) 
                 AND ((CHARINDEX(P.CDSERVFILI, @P_CDSERVFILI) <> 0) OR (@P_CDSERVFILI = 'T')) 
                 AND (P.CDFILIAL     = @P_CDFILCENTPME     ) 
                 AND (P.DTCARDIAPME BETWEEN @P_DTINICIAL AND @P_DTFINAL) 
                 AND (NOT EXISTS(SELECT CDFILIAL
                                   FROM CARDIAPME C
                                  WHERE (C.CDFILCENTPME = P.CDFILCENTPME ) 
                                    AND (C.NRCARDPME    = P.NRCARDPME    ) 
                                    AND (C.CDSERVFILI   = P.CDSERVFILI   ) 
                                    AND (C.CDFILIAL     = @P_CDFILIAL    ) 
                                    AND (C.DTCARDIAPME  = P.DTCARDIAPME  ) 
                                    AND (C.IDCARDESPEC  = 'S'            )))
               UNION ALL
              SELECT CDFILCENTPME, NRCARDPME, NRCARDIAPME, @P_CDFILIAL AS CDFILIAL, CDSERVFILI, DTCARDIAPME
                FROM CARDIAPME
               WHERE (CDFILCENTPME = @P_CDFILCENTPME ) 
                 AND ((CHARINDEX(CDSERVFILI, @P_CDSERVFILI) <> 0) OR (@P_CDSERVFILI = 'T')) 
                 AND (CDFILIAL     = @P_CDFILCENTPME ) 
                 AND (DTCARDIAPME BETWEEN @P_DTINICIAL AND @P_DTFINAL) 
                 AND (IDCARDESPEC  = 'S'             )) CD
       WHERE (CD.CDFILCENTPME    = CC.CDFILCENTPME ) 
         AND (CD.NRCARDPME       = CC.NRCARDPME    ) 
         AND (CD.NRCARDIAPME     = CC.NRCARDIAPME  ) 
         AND (RP.CDFILAUXPRAT    = 'P'             ) 
         AND (CC.CDPRATO         = RP.CDPRATO      ) 
         AND (PRODFILI.CDFILIAL  = CD.CDFILCENTPME ) 
         AND (PRODFILI.CDPRODUTO = PR.CDPRODUTO    ) 
         AND (CHARINDEX(NP.CDNUTRIENTE, @P_NUTRIENTES) <> 0) 
         AND (RP.CDPRODUTO = NP.CDPRODUTO          ) 
         AND (RP.CDPRODUTO = PR.CDPRODUTO          ) 
         AND (CD.CDFILCENTPME    = CP.CDFILCENTPME ) 
         AND (CD.NRCARDPME       = CP.NRCARDPME    ) 
         AND (CP.CDTIPOCARD      = @P_CDTIPOCARD)    
         AND (NOT EXISTS (SELECT CDPRATO
                            FROM RECETPCARD
                           WHERE (CDFILAUXPRAT = CC.CDFILAUXPRAT ) 
                             AND (CDPRATO      = CC.CDPRATO      ) 
                             AND (CDFILCENTPME = CD.CDFILCENTPME )
                             AND (CDTIPOCARD   = CP.CDTIPOCARD   )))
         AND (NOT EXISTS (SELECT CDPRATO
                            FROM RECEFILI
                           WHERE (CDFILAUXPRAT = CC.CDFILAUXPRAT ) 
                             AND (CDPRATO      = CC.CDPRATO      ) 
                             AND (CDFILIAL     = CD.CDFILIAL     )))
         AND (NOT EXISTS (SELECT CDPRATO
                            FROM RECESERV
                           WHERE (CDFILAUXPRAT = CC.CDFILAUXPRAT ) 
                             AND (CDPRATO      = CC.CDPRATO      ) 
                             AND (CDFILIAL     = CD.CDFILIAL     ) 
                             AND (CDSERVFILI   = CD.CDSERVFILI   )));
   OPEN CUR_NUTRTRAB;
   FETCH NEXT FROM CUR_NUTRTRAB INTO @V_NUTRTRAB_CDFILCENTPME,
                                     @V_NUTRTRAB_CDFILIAL,
                                     @V_NUTRTRAB_CDSERVFILI,
                                     @V_NUTRTRAB_DTCARDIAPME,
                                     @V_NUTRTRAB_CDDIETPAD,
                                     @V_NUTRTRAB_NRSEQPRACPME,
                                     @V_NUTRTRAB_CDTIPOPRAT,
                                     @V_NUTRTRAB_CDFILAUXPRAT,
                                     @V_NUTRTRAB_CDPRATO,
                                     @V_NUTRTRAB_CDPRODUTO,
                                     @V_NUTRTRAB_SGUNIDPROD,
                                     @V_NUTRTRAB_CDNUTRIENTE,
                                     @V_NUTRTRAB_QTPRODUTO,
                                     @V_NUTRTRAB_QTNUTPROD,
                                     @V_NUTRTRAB_VRPECONSCARD,
                                     @V_NUTRTRAB_QTPRODPRATT;

   WHILE (@@FETCH_STATUS = 0) BEGIN
      INSERT INTO NUTRTRAB
         (NRSEQUNUTR,
          CDFILINUTR,
          CDSERVNUTR,
          DTREFENUTR,
          CDDIETNUTR,
          NRSEQPRATNUT,
          CDTPPRATNUTR,
          CDFAPRATNUTR,
          CDPRATNUTR,
          CDPRODNUTR,
          CDNUTRCALC,
          QTPRODNUTR,
          QTNUTRCALC,
          QTPROTLIQU,
          VRCALORNUTR,
          VRPECONSNUTR,
          SGUNIDPRODT,
          QTPRODPRATT)
      VALUES
         (@P_NRSEQUNUTR,
          @V_NUTRTRAB_CDFILIAL,
          @V_NUTRTRAB_CDSERVFILI,
          @V_NUTRTRAB_DTCARDIAPME,
          @V_NUTRTRAB_CDDIETPAD,
          @V_NUTRTRAB_NRSEQPRACPME,
          @V_NUTRTRAB_CDTIPOPRAT,
          @V_NUTRTRAB_CDFILAUXPRAT,
          @V_NUTRTRAB_CDPRATO,
          @V_NUTRTRAB_CDPRODUTO,
          @V_NUTRTRAB_CDNUTRIENTE,
          @V_NUTRTRAB_QTPRODUTO,
          @V_NUTRTRAB_QTNUTPROD,
          0,
          0,
          @V_NUTRTRAB_VRPECONSCARD,
          @V_NUTRTRAB_SGUNIDPROD,
          @V_NUTRTRAB_QTPRODPRATT);
      FETCH NEXT FROM CUR_NUTRTRAB INTO @V_NUTRTRAB_CDFILCENTPME,
                                        @V_NUTRTRAB_CDFILIAL,
                                        @V_NUTRTRAB_CDSERVFILI,
                                        @V_NUTRTRAB_DTCARDIAPME,
                                        @V_NUTRTRAB_CDDIETPAD,
                                        @V_NUTRTRAB_NRSEQPRACPME,
                                        @V_NUTRTRAB_CDTIPOPRAT,
                                        @V_NUTRTRAB_CDFILAUXPRAT,
                                        @V_NUTRTRAB_CDPRATO,
                                        @V_NUTRTRAB_CDPRODUTO,
                                        @V_NUTRTRAB_SGUNIDPROD,
                                        @V_NUTRTRAB_CDNUTRIENTE,
                                        @V_NUTRTRAB_QTPRODUTO,
                                        @V_NUTRTRAB_QTNUTPROD,
                                        @V_NUTRTRAB_VRPECONSCARD,
                                        @V_NUTRTRAB_QTPRODPRATT;
   END;
   CLOSE CUR_NUTRTRAB;
   DEALLOCATE CUR_NUTRTRAB;

   /* ------------------------- CALCULO DO DNPCal --------------------------- */
   IF @P_IDNDPCAL = 'S'
   BEGIN
      /* ---------------- GRAVA O VALOR DE PROTEINA LIQUIDA (NPU) ----------------- */
      UPDATE
         NUTRTRAB
      SET
         QTPROTLIQU = (SELECT
                          ISNULL(MAX(VRFATCALNDPC) * QTNUTRCALC,0)
                       FROM
                          NDPCAL
                       WHERE
                          CDPRODUTO = (SELECT
                                          MAX(CDPRODUTO)
                                       FROM
                                          NDPCAL
                                       WHERE
                                          CHARINDEX(CDPRODUTO, NUTRTRAB.CDPRODNUTR) = 1
                                      )
                       )
      WHERE
         CDNUTRCALC = (SELECT MAX(CDPROTEINA) FROM PARAMGERAL) AND
         NRSEQUNUTR = @P_NRSEQUNUTR;

      /* --------------------- GRAVA O VALOR DE CALORIAS -------------------- */
      UPDATE
         NUTRTRAB
      SET
         VRCALORNUTR = QTNUTRCALC
      WHERE
         CDNUTRCALC = (SELECT MAX(CDCALORIAS) FROM PARAMGERAL) AND
         NRSEQUNUTR = @P_NRSEQUNUTR;

   END;
END;
GO

SET QUOTED_IDENTIFIER OFF
GO

SET ANSI_NULLS ON
GO

-- VERSAO --
EXEC ATUVEROBJ 'NUTRIENTE_DO_CARDAPIO_PME','5.05.009';
GO

